# Copyright 2017-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You
# may not use this file except in compliance with the License. A copy of
# the License is located at
#
#     http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is
# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific
# language governing permissions and limitations under the License.
"""Placeholder docstring"""
from __future__ import absolute_import

TF_VERSION = "1.11"
"""Default TF version for when the framework version is not specified.
This is no longer updated so as to not break existing workflows.
"""

LATEST_VERSION = "2.1.0"
"""The latest version of TensorFlow included in the SageMaker pre-built Docker images."""

LATEST_PY2_VERSION = "2.1.0"
